@@ -73,13 +73,13 @@ class Payment(MuviBase):
 
         payment_response = self.sdk.payment().create(payment_data_mp)
         if payment_response['status'] < 400:
-            return self.ok(_format(payment_response['response']), status=payment_response['status'])
+            return self.ok(response=_format(payment_response['response']), status=payment_response['status'])
 
-        return self.error(payment_response['response'], status=payment_response['status'])
+        return self.error(response=payment_response['response'], status=payment_response['status'])
 
     def get(self, payment_id: int):
         payment_response = self.sdk.payment().get(payment_id)
         if payment_response['status'] < 400:
-            return self.ok(payment_response['response'], status=payment_response['status'])
+            return self.ok(response=payment_response['response'], status=payment_response['status'])
 
-        return self.error(payment_response['response'], status=payment_response['status'])
+        return self.error(response=payment_response['response'], status=payment_response['status'])
